@@ -24,7 +24,6 @@ from oslo_config import cfg
 from oslo_utils import encodeutils
 from oslo_utils import importutils
 from oslo_utils import units
-import six
 
 from glance_store import capabilities
 from glance_store import exceptions
@@ -40,7 +39,15 @@ This option will be used to provide a constructive information about
 the store backend to end users. Using /v2/stores-info call user can
 seek more information on all available backends.
 
-"""))
+""")),
+    cfg.IntOpt('weight',
+               help=_("""
+This option is used to define a relative weight for this store over
+any others that are configured. The actual value of the weight is meaningless
+and only serves to provide a "sort order" compared to others. Any stores
+with the same weight will be treated as equivalent.
+"""),
+               default=0),
 ]
 
 
@@ -80,6 +87,15 @@ class Store(capabilities.StoreCapability):
     def url_prefix(self):
         return self._url_prefix
 
+    @property
+    def weight(self):
+        if self.backend_group is None:
+            # NOTE(danms): A backend with no config group can not have a
+            # weight set, so just return the default
+            return 0
+        else:
+            return getattr(self.conf, self.backend_group).weight
+
     def configure(self, re_raise_bsc=False):
         """
         Configure the store to use the stored configuration options
@@ -93,7 +109,7 @@ class Store(capabilities.StoreCapability):
             self.configure_add()
         except exceptions.BadStoreConfiguration as e:
             self.unset_capabilities(capabilities.BitMasks.WRITE_ACCESS)
-            msg = (_(u"Failed to configure store correctly: %s "
+            msg = (_("Failed to configure store correctly: %s "
                      "Disabling add method.")
                    % encodeutils.exception_to_unicode(e))
             LOG.warning(msg)
@@ -257,8 +273,7 @@ def back_compat_add(store_add_fun):
             # everything is present, including hashing_algo
             back_compat_required = False
         elif ('hashing_algo' in kwargs or
-              (num_args >= p_algo + 1 and isinstance(args[p_algo],
-                                                     six.string_types))):
+              (num_args >= p_algo + 1 and isinstance(args[p_algo], str))):
             # there is a hashing_algo argument present
             back_compat_required = False
         else:
