@@ -17,7 +17,6 @@ import hashlib
 import io
 from unittest import mock
 
-from oslo_utils.secretutils import md5
 from oslo_utils import units
 
 from glance_store._drivers import rbd as rbd_store
@@ -434,8 +433,8 @@ class TestStore(base.StoreBaseTest,
         file_size = 5 * units.Ki  # 5K
         file_contents = b"*" * file_size
         image_file = io.BytesIO(file_contents)
-        expected_checksum = md5(file_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(file_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(file_contents).hexdigest()
 
         with mock.patch.object(rbd_store.rbd.Image, 'write'):
@@ -508,8 +507,8 @@ class TestStore(base.StoreBaseTest,
 
         image_id = 'fake_image_id'
         image_file = io.BytesIO(content)
-        expected_checksum = md5(content,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(content,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(content).hexdigest()
 
         with mock.patch.object(rbd_store.rbd.Image, 'write') as mock_write:
