@@ -20,19 +20,16 @@ from unittest import mock
 
 import fixtures
 import hashlib
+import http.client
+import importlib
+import io
 import tempfile
 import uuid
 
 from oslo_config import cfg
 from oslo_utils import encodeutils
-from oslo_utils.secretutils import md5
 from oslo_utils import units
 import requests_mock
-import six
-from six import moves
-from six.moves import http_client
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
-from six.moves import range
 import swiftclient
 
 from glance_store._drivers.swift import connection_manager as manager
@@ -84,14 +81,14 @@ class SwiftTests(object):
             'glance/%s' % FAKE_UUID2: {'x-static-large-object': 'true', },
         }
         fixture_objects = {
-            'glance/%s' % FAKE_UUID: six.BytesIO(b"*" * FIVE_KB),
-            'glance/%s' % FAKE_UUID2: six.BytesIO(b"*" * FIVE_KB),
+            'glance/%s' % FAKE_UUID: io.BytesIO(b"*" * FIVE_KB),
+            'glance/%s' % FAKE_UUID2: io.BytesIO(b"*" * FIVE_KB),
         }
 
         def fake_head_container(url, token, container, **kwargs):
             if container not in fixture_containers:
                 msg = "No container %s found" % container
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
             return fixture_container_headers
 
@@ -113,7 +110,7 @@ class SwiftTests(object):
                 if kwargs.get('headers'):
                     manifest = kwargs.get('headers').get('X-Object-Manifest')
                     etag = kwargs.get('headers') \
-                                 .get('ETag', md5(
+                                 .get('ETag', hashlib.md5(
                                      b'', usedforsecurity=False).hexdigest())
                     fixture_headers[fixture_key] = {
                         'manifest': True,
@@ -123,10 +120,10 @@ class SwiftTests(object):
                     fixture_objects[fixture_key] = None
                     return etag
                 if hasattr(contents, 'read'):
-                    fixture_object = six.BytesIO()
+                    fixture_object = io.BytesIO()
                     read_len = 0
                     chunk = contents.read(CHUNKSIZE)
-                    checksum = md5(usedforsecurity=False)
+                    checksum = hashlib.md5(usedforsecurity=False)
                     while chunk:
                         fixture_object.write(chunk)
                         read_len += len(chunk)
@@ -134,15 +131,15 @@ class SwiftTests(object):
                         chunk = contents.read(CHUNKSIZE)
                     etag = checksum.hexdigest()
                 else:
-                    fixture_object = six.BytesIO(contents)
+                    fixture_object = io.BytesIO(contents)
                     read_len = len(contents)
-                    etag = md5(fixture_object.getvalue(),
-                               usedforsecurity=False).hexdigest()
+                    etag = hashlib.md5(fixture_object.getvalue(),
+                                       usedforsecurity=False).hexdigest()
                 if read_len > MAX_SWIFT_OBJECT_SIZE:
                     msg = ('Image size:%d exceeds Swift max:%d' %
                            (read_len, MAX_SWIFT_OBJECT_SIZE))
                     raise swiftclient.ClientException(
-                        msg, http_status=http_client.REQUEST_ENTITY_TOO_LARGE)
+                        msg, http_status=http.client.REQUEST_ENTITY_TOO_LARGE)
                 fixture_objects[fixture_key] = fixture_object
                 fixture_headers[fixture_key] = {
                     'content-length': read_len,
@@ -152,14 +149,14 @@ class SwiftTests(object):
                 msg = ("Object PUT failed - Object with key %s already exists"
                        % fixture_key)
                 raise swiftclient.ClientException(
-                    msg, http_status=http_client.CONFLICT)
+                    msg, http_status=http.client.CONFLICT)
 
         def fake_get_object(conn, container, name, **kwargs):
             # GET returns the tuple (list of headers, file object)
             fixture_key = "%s/%s" % (container, name)
             if fixture_key not in fixture_headers:
                 msg = "Object GET failed"
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
 
             byte_range = None
@@ -176,7 +173,7 @@ class SwiftTests(object):
                 chunk_keys = sorted([k for k in fixture_headers.keys()
                                      if k.startswith(fixture_key) and
                                      k != fixture_key])
-                result = six.BytesIO()
+                result = io.BytesIO()
                 for key in chunk_keys:
                     result.write(fixture_objects[key].getvalue())
             else:
@@ -184,7 +181,7 @@ class SwiftTests(object):
 
             if byte_range is not None:
                 start = int(byte_range.split('=')[1].strip('-'))
-                result = six.BytesIO(result.getvalue()[start:])
+                result = io.BytesIO(result.getvalue()[start:])
                 fixture_headers[fixture_key]['content-length'] = len(
                     result.getvalue())
 
@@ -197,7 +194,7 @@ class SwiftTests(object):
                 return fixture_headers[fixture_key]
             except KeyError:
                 msg = "Object HEAD failed - Object does not exist"
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
 
         def fake_delete_object(url, token, container, name, **kwargs):
@@ -205,7 +202,7 @@ class SwiftTests(object):
             fixture_key = "%s/%s" % (container, name)
             if fixture_key not in fixture_headers:
                 msg = "Object DELETE failed - Object does not exist"
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
             else:
                 del fixture_headers[fixture_key]
@@ -317,7 +314,7 @@ class SwiftTests(object):
         (image_swift, image_size) = self.store.get(loc, context=ctxt)
         resp_full = b''.join([chunk for chunk in image_swift.wrapped])
         resp_half = resp_full[:len(resp_full) // 2]
-        resp_half = six.BytesIO(resp_half)
+        resp_half = io.BytesIO(resp_half)
         manager = self.store.get_manager(loc.store_location, ctxt)
 
         image_swift.wrapped = swift.swift_retry_iter(resp_half, image_size,
@@ -393,18 +390,18 @@ class SwiftTests(object):
                 mock.Mock(return_value=False))
     def test_add(self):
         """Test that we can add an image via the swift backend."""
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = md5(expected_swift_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_swift_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = "swift+https://tenant%%3Auser1:key@localhost:8080/glance/%s"
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -433,7 +430,7 @@ class SwiftTests(object):
         conf = copy.deepcopy(SWIFT_CONF)
         conf['default_swift_reference'] = 'store_2'
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -441,7 +438,7 @@ class SwiftTests(object):
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
         expected_image_id = str(uuid.uuid4())
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
         loc = 'swift+config://store_2/glance/%s'
@@ -464,7 +461,7 @@ class SwiftTests(object):
         expected_container = 'container_' + expected_image_id
         loc = 'swift+https://some_endpoint/%s/%s'
         expected_location = loc % (expected_container, expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -524,15 +521,16 @@ class SwiftTests(object):
             expected_swift_size = FIVE_KB
             expected_swift_contents = b"*" * expected_swift_size
             expected_checksum = \
-                md5(expected_swift_contents, usedforsecurity=False).hexdigest()
+                hashlib.md5(expected_swift_contents,
+                            usedforsecurity=False).hexdigest()
 
-            image_swift = six.BytesIO(expected_swift_contents)
+            image_swift = io.BytesIO(expected_swift_contents)
 
             global SWIFT_PUT_OBJECT_CALLS
             SWIFT_PUT_OBJECT_CALLS = 0
             conf['default_swift_reference'] = variation
             self.config(group="swift1", **conf)
-            moves.reload_module(swift)
+            importlib.reload(swift)
             self.mock_keystone_client()
             self.store = Store(self.conf, backend="swift1")
             self.store.configure()
@@ -565,13 +563,13 @@ class SwiftTests(object):
         conf['swift_store_create_container_on_put'] = False
         conf['swift_store_container'] = 'noexist'
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
 
         self.store = Store(self.conf, backend='swift1')
         self.store.configure()
 
-        image_swift = six.BytesIO(b"nevergonnamakeit")
+        image_swift = io.BytesIO(b"nevergonnamakeit")
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -599,12 +597,12 @@ class SwiftTests(object):
         """
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = md5(expected_swift_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_swift_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = 'swift+config://ref1/noexist/%s'
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -613,7 +611,7 @@ class SwiftTests(object):
         conf['swift_store_create_container_on_put'] = True
         conf['swift_store_container'] = 'noexist'
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -646,13 +644,13 @@ class SwiftTests(object):
         """
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = md5(expected_swift_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_swift_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         container = 'randomname_' + expected_image_id[:2]
         loc = 'swift+config://ref1/%s/%s'
         expected_location = loc % (container, expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -662,7 +660,7 @@ class SwiftTests(object):
         conf['swift_store_container'] = 'randomname'
         conf['swift_store_multiple_containers_seed'] = 2
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
 
         self.store = Store(self.conf, backend="swift1")
@@ -700,7 +698,7 @@ class SwiftTests(object):
         conf['swift_store_container'] = 'randomname'
         conf['swift_store_multiple_containers_seed'] = 2
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
 
         expected_image_id = str(uuid.uuid4())
@@ -709,7 +707,7 @@ class SwiftTests(object):
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
 
-        image_swift = six.BytesIO(b"nevergonnamakeit")
+        image_swift = io.BytesIO(b"nevergonnamakeit")
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -737,7 +735,7 @@ class SwiftTests(object):
         base_byte = b"12345678"
         swift_contents = base_byte * (swift_size // 8)
         image_id = str(uuid.uuid4())
-        image_swift = six.BytesIO(swift_contents)
+        image_swift = io.BytesIO(swift_contents)
 
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -784,7 +782,7 @@ class SwiftTests(object):
         base_byte = b"12345678"
         swift_contents = base_byte * (swift_size // 8)
         image_id = str(uuid.uuid4())
-        image_swift = six.BytesIO(swift_contents)
+        image_swift = io.BytesIO(swift_contents)
 
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -823,7 +821,7 @@ class SwiftTests(object):
         expected_container = 'container_' + expected_image_id
         loc = 'swift+https://some_endpoint/%s/%s'
         expected_location = loc % (expected_container, expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -871,12 +869,12 @@ class SwiftTests(object):
         """
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = md5(expected_swift_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_swift_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = 'swift+config://ref1/glance/%s'
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -926,12 +924,12 @@ class SwiftTests(object):
         # Set up a 'large' image of 5KB
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = md5(expected_swift_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_swift_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = 'swift+config://ref1/glance/%s'
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -986,7 +984,7 @@ class SwiftTests(object):
         """
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
-        image_swift = six.BytesIO(b"nevergonnamakeit")
+        image_swift = io.BytesIO(b"nevergonnamakeit")
         self.assertRaises(exceptions.Duplicate,
                           self.store.add,
                           FAKE_UUID, image_swift, 0)
@@ -1033,7 +1031,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -1053,7 +1051,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
 
@@ -1075,7 +1073,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -1096,7 +1094,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         # mock client because v3 uses it to receive auth_info
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
@@ -1116,7 +1114,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
 
@@ -1155,7 +1153,7 @@ class SwiftTests(object):
 
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
 
@@ -1461,15 +1459,72 @@ class TestStoreAuthV3(TestStoreAuthV1):
             uri, "swift1", conf=self.conf)
         ctxt = mock.MagicMock()
         store.init_client(location=loc.store_location, context=ctxt)
-        # check that keystone was initialized correctly
-        tenant = None if store.auth_version == '1' else "tenant"
-        username = "tenant:user1" if store.auth_version == '1' else "user1"
         mock_identity.V3Password.assert_called_once_with(
             auth_url=loc.store_location.swift_url + '/',
-            username=username, password="key",
-            project_name=tenant,
-            project_domain_id='default', project_domain_name='default',
-            user_domain_id='default', user_domain_name='default',)
+            username="user1", password="key",
+            project_name="tenant",
+            project_domain_id='default', project_domain_name=None,
+            user_domain_id='default', user_domain_name=None,)
+        mock_session.Session.assert_called_once_with(
+            auth=mock_identity.V3Password(), verify=True)
+        mock_client.Client.assert_called_once_with(
+            session=mock_session.Session())
+
+    @mock.patch("glance_store._drivers.swift.store.ks_identity")
+    @mock.patch("glance_store._drivers.swift.store.ks_session")
+    @mock.patch("glance_store._drivers.swift.store.ks_client")
+    def test_init_client_single_tenant_with_domain_ids(self,
+                                                       mock_client,
+                                                       mock_session,
+                                                       mock_identity):
+        """Test that keystone client was initialized correctly"""
+        conf = self.getConfig()
+        conf['default_swift_reference'] = 'ref4'
+        self.config(group="swift1", **conf)
+        store = Store(self.conf, backend="swift1")
+        store.configure()
+        uri = "swift://%s:key@auth_address/glance/%s" % (
+            self.swift_store_user, FAKE_UUID)
+        loc = location.get_location_from_uri_and_backend(
+            uri, "swift1", conf=self.conf)
+        ctxt = mock.MagicMock()
+        store.init_client(location=loc.store_location, context=ctxt)
+        mock_identity.V3Password.assert_called_once_with(
+            auth_url=loc.store_location.swift_url + '/',
+            username="user1", password="key",
+            project_name="tenant",
+            project_domain_id='projdomainid', project_domain_name=None,
+            user_domain_id='userdomainid', user_domain_name=None)
+        mock_session.Session.assert_called_once_with(
+            auth=mock_identity.V3Password(), verify=True)
+        mock_client.Client.assert_called_once_with(
+            session=mock_session.Session())
+
+    @mock.patch("glance_store._drivers.swift.store.ks_identity")
+    @mock.patch("glance_store._drivers.swift.store.ks_session")
+    @mock.patch("glance_store._drivers.swift.store.ks_client")
+    def test_init_client_single_tenant_with_domain_names(self,
+                                                         mock_client,
+                                                         mock_session,
+                                                         mock_identity):
+        """Test that keystone client was initialized correctly"""
+        conf = self.getConfig()
+        conf['default_swift_reference'] = 'ref5'
+        self.config(group="swift1", **conf)
+        store = Store(self.conf, backend="swift1")
+        store.configure()
+        uri = "swift://%s:key@auth_address/glance/%s" % (
+            self.swift_store_user, FAKE_UUID)
+        loc = location.get_location_from_uri_and_backend(
+            uri, "swift1", conf=self.conf)
+        ctxt = mock.MagicMock()
+        store.init_client(location=loc.store_location, context=ctxt)
+        mock_identity.V3Password.assert_called_once_with(
+            auth_url=loc.store_location.swift_url + '/',
+            username="user1", password="key",
+            project_name="tenant",
+            project_domain_id=None, project_domain_name='projdomain',
+            user_domain_id=None, user_domain_name='userdomain')
         mock_session.Session.assert_called_once_with(
             auth=mock_identity.V3Password(), verify=True)
         mock_client.Client.assert_called_once_with(
@@ -1896,7 +1951,7 @@ class TestMultiTenantStoreContext(base.MultiStoreBaseTest):
         store = Store(self.conf, backend="swift1")
         store.configure()
         content = b'Some data'
-        pseudo_file = six.BytesIO(content)
+        pseudo_file = io.BytesIO(content)
         store.add('123', pseudo_file, len(content),
                   context=self.ctx)
         self.assertEqual(b'0123',
@@ -1939,7 +1994,7 @@ class TestCreatingLocations(base.MultiStoreBaseTest):
         self.store.configure()
         self.register_store_backend_schemes(self.store, 'swift', 'swift1')
 
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.addCleanup(self.conf.reset)
 
         service_catalog = [
@@ -1969,7 +2024,7 @@ class TestCreatingLocations(base.MultiStoreBaseTest):
         conf.update({'swift_store_config_file': self.swift_config_file})
         conf['default_swift_reference'] = 'ref1'
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
 
         store = swift.SingleTenantStore(self.conf, backend="swift1")
         store.configure()
@@ -2084,14 +2139,15 @@ class TestChunkReader(base.MultiStoreBaseTest):
         """
         CHUNKSIZE = 100
         data = b'*' * units.Ki
-        expected_checksum = md5(data, usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(data,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(data).hexdigest()
         data_file = tempfile.NamedTemporaryFile()
         data_file.write(data)
         data_file.flush()
         infile = open(data_file.name, 'rb')
         bytes_read = 0
-        checksum = md5(usedforsecurity=False)
+        checksum = hashlib.md5(usedforsecurity=False)
         os_hash_value = hashlib.sha256()
         while True:
             cr = swift.ChunkReader(infile, checksum, os_hash_value, CHUNKSIZE)
@@ -2113,10 +2169,10 @@ class TestChunkReader(base.MultiStoreBaseTest):
         Replicate what goes on in the Swift driver with the
         repeated creation of the ChunkReader object
         """
-        expected_checksum = md5(b'', usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(b'', usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(b'').hexdigest()
         CHUNKSIZE = 100
-        checksum = md5(usedforsecurity=False)
+        checksum = hashlib.md5(usedforsecurity=False)
         os_hash_value = hashlib.sha256()
         data_file = tempfile.NamedTemporaryFile()
         infile = open(data_file.name, 'rb')
